.. _lts_next:

============
The Next LTS
============

The Long Term Stability releases of Avocado are the result of the
accumulated changes on regular (non-LTS) releases.

This section tracks the changes introduced on each regular (non-LTS)
Avocado release, and gives a sneak preview of what will make into the
next LTS release.

What's new?
===========

When compared to the last LTS (82.x), the main changes to be
introduced by the next LTS version are:

Test Writers
------------

Test APIs
~~~~~~~~~

Utility APIs
~~~~~~~~~~~~

Users
-----

Output Plugins
~~~~~~~~~~~~~~

Test Loader Plugins
~~~~~~~~~~~~~~~~~~~

Varianter Plugins
~~~~~~~~~~~~~~~~~

Test Runner Plugins
~~~~~~~~~~~~~~~~~~~

Complete list of changes
========================

For a complete list of changes between the last LTS release (82.0) and
this release, please check out `the Avocado commit changelog
<https://github.com/avocado-framework/avocado/compare/82.0...master>`_.
